% Auto-generated chapter 12 for bukhari
% Hadiths in this chapter: 6

\hadithdefcmd{bukhari}{942}{حَدَّثَنَا أَبُو الْيَمَانِ، قَالَ أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ سَأَلْتُهُ هَلْ صَلَّى النَّبِيُّ صلى الله عليه وسلم يَعْنِي صَلاَةَ الْخَوْفِ قَالَ أَخْبَرَنِي سَالِمٌ أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ ـ رضى الله عنهما ـ قَالَ غَزَوْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم قِبَلَ نَجْدٍ، فَوَازَيْنَا الْعَدُوَّ فَصَافَفْنَا لَهُمْ فَقَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّي لَنَا فَقَامَتْ طَائِفَةٌ مَعَهُ تُصَلِّي، وَأَقْبَلَتْ طَائِفَةٌ عَلَى الْعَدُوِّ وَرَكَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِمَنْ مَعَهُ، وَسَجَدَ سَجْدَتَيْنِ، ثُمَّ انْصَرَفُوا مَكَانَ الطَّائِفَةِ الَّتِي لَمْ تُصَلِّ، فَجَاءُوا، فَرَكَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِهِمْ رَكْعَةً، وَسَجَدَ سَجْدَتَيْنِ ثُمَّ سَلَّمَ، فَقَامَ كُلُّ وَاحِدٍ مِنْهُمْ فَرَكَعَ لِنَفْسِهِ رَكْعَةً وَسَجَدَ سَجْدَتَيْنِ‏.‏\hadithno{942}\hadithtrans{Narrated Shu'aib:I asked Az-Zuhri, "Did the Prophet (ﷺ) ever offer the Fear Prayer?" Az-Zuhri said, "I was told by Salim that `Abdullah bin `Umar had said, 'I took part in a holy battle with Allah's Messenger (ﷺ) in Najd. We faced the enemy and arranged ourselves in rows. Then Allah's Messenger (ﷺ) stood up to lead the prayer and one party stood to pray with him while the other faced the enemy. Allah's Messenger (ﷺ) and the former party bowed and performed two prostrations. Then that party left and took the place of those who had not prayed. Allah's Messenger (ﷺ) prayed one rak`a (with the latter) and performed two prostrations and finished his prayer with Taslim. Then everyone of them bowed once and performed two prostrations individually}}
\hadithdefcmd{bukhari}{943}{حَدَّثَنَا سَعِيدُ بْنُ يَحْيَى بْنِ سَعِيدٍ الْقُرَشِيُّ، قَالَ حَدَّثَنِي أَبِي قَالَ، حَدَّثَنَا ابْنُ جُرَيْجٍ، عَنْ مُوسَى بْنِ عُقْبَةَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، نَحْوًا مِنْ قَوْلِ مُجَاهِدٍ إِذَا اخْتَلَطُوا قِيَامًا‏.‏ وَزَادَ ابْنُ عُمَرَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏ "‏ وَإِنْ كَانُوا أَكْثَرَ مِنْ ذَلِكَ فَلْيُصَلُّوا قِيَامًا وَرُكْبَانًا ‏"‏‏.‏\hadithno{943}\hadithtrans{Narrated Nafi`:Ibn `Umar said something similar to Mujahid's saying: Whenever (Muslims and non-Muslims) stand face to face in battle, the Muslims can pray while standing. Ibn `Umar added, "The Prophet (ﷺ) said, 'If the number of the enemy is greater than the Muslims, they can pray while standing or riding (individually)}}
\hadithdefcmd{bukhari}{944}{حَدَّثَنَا حَيْوَةُ بْنُ شُرَيْحٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ حَرْبٍ، عَنِ الزُّبَيْدِيِّ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ قَامَ النَّبِيُّ صلى الله عليه وسلم وَقَامَ النَّاسُ مَعَهُ، فَكَبَّرَ وَكَبَّرُوا مَعَهُ، وَرَكَعَ وَرَكَعَ نَاسٌ مِنْهُمْ، ثُمَّ سَجَدَ وَسَجَدُوا مَعَهُ، ثُمَّ قَامَ لِلثَّانِيَةِ فَقَامَ الَّذِينَ سَجَدُوا وَحَرَسُوا إِخْوَانَهُمْ، وَأَتَتِ الطَّائِفَةُ الأُخْرَى فَرَكَعُوا وَسَجَدُوا مَعَهُ، وَالنَّاسُ كُلُّهُمْ فِي صَلاَةٍ، وَلَكِنْ يَحْرُسُ بَعْضُهُمْ بَعْضًا‏.‏\hadithno{944}\hadithtrans{Narrated Ibn `Abbas:Once the Prophet (ﷺ) led the fear prayer and the people stood behind him. He said Takbir (Allahu-Akbar) and the people said the same. He bowed and some of them bowed. Then he prostrated and they also prostrated. Then he stood for the second rak`a and those who had prayed the first rak`a left and guarded their brothers. The second party joined him and performed bowing and prostration with him. All the people were in prayer but they were guarding one another during the prayer}}
\hadithdefcmd{bukhari}{945}{حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا وَكِيعٌ، عَنْ عَلِيِّ بْنِ مُبَارَكٍ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ أَبِي سَلَمَةَ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ جَاءَ عُمَرُ يَوْمَ الْخَنْدَقِ، فَجَعَلَ يَسُبُّ كُفَّارَ قُرَيْشٍ وَيَقُولُ يَا رَسُولَ اللَّهِ مَا صَلَّيْتُ الْعَصْرَ حَتَّى كَادَتِ الشَّمْسُ أَنْ تَغِيبَ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ وَأَنَا وَاللَّهِ مَا صَلَّيْتُهَا بَعْدُ ‏"‏‏.‏ قَالَ فَنَزَلَ إِلَى بُطْحَانَ فَتَوَضَّأَ، وَصَلَّى الْعَصْرَ بَعْدَ مَا غَابَتِ الشَّمْسُ، ثُمَّ صَلَّى الْمَغْرِبَ بَعْدَهَا‏.‏\hadithno{945}\hadithtrans{Narrated Jabir bin `Abdullah:On the day of the Khandaq `Umar came, cursing the disbelievers of Quraish and said, "O Allah's Apostle! I have not offered the `Asr prayer and the sun has set." The Prophet (ﷺ) replied, "By Allah! I too, have not offered the prayer yet. "The Prophet (ﷺ) then went to Buthan, performed ablution and performed the `Asr prayer after the sun had set and then offered the Maghrib prayer after it}}
\hadithdefcmd{bukhari}{946}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدِ بْنِ أَسْمَاءَ، قَالَ حَدَّثَنَا جُوَيْرِيَةُ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم لَنَا لَمَّا رَجَعَ مِنَ الأَحْزَابِ ‏ "‏ لاَ يُصَلِّيَنَّ أَحَدٌ الْعَصْرَ إِلاَّ فِي بَنِي قُرَيْظَةَ ‏"‏‏.‏ فَأَدْرَكَ بَعْضُهُمُ الْعَصْرَ فِي الطَّرِيقِ فَقَالَ بَعْضُهُمْ لاَ نُصَلِّي حَتَّى نَأْتِيَهَا، وَقَالَ بَعْضُهُمْ بَلْ نُصَلِّي لَمْ يُرَدْ مِنَّا ذَلِكَ‏.‏ فَذُكِرَ لِلنَّبِيِّ صلى الله عليه وسلم فَلَمْ يُعَنِّفْ وَاحِدًا مِنْهُمْ‏.‏\hadithno{946}\hadithtrans{Narrated Ibn `Umar:When the Prophet (ﷺ) returned from the battle of Al-Ahzab (The confederates), he said to us, "None should offer the 'Asr prayer but at Bani Quraiza." The 'Asr prayer became due for some of them on the way. Some of them decided not to offer the Salat but at Bani Quraiza while others decided to offer the Salat on the spot and said that the intention of the Prophet (ﷺ) was not what the former party had understood. And when that was told to the Prophet (ﷺ) he did not blame anyone of them}}
\hadithdefcmd{bukhari}{947}{حَدَّثَنَا مُسَدَّدٌ، قَالَ حَدَّثَنَا حَمَّادٌ، عَنْ عَبْدِ الْعَزِيزِ بْنِ صُهَيْبٍ، وَثَابِتٍ الْبُنَانِيِّ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم صَلَّى الصُّبْحَ بِغَلَسٍ ثُمَّ رَكِبَ فَقَالَ ‏ "‏ اللَّهُ أَكْبَرُ خَرِبَتْ خَيْبَرُ، إِنَّا إِذَا نَزَلْنَا بِسَاحَةِ قَوْمٍ فَسَاءَ صَبَاحُ الْمُنْذَرِينَ ‏"‏‏.‏ فَخَرَجُوا يَسْعَوْنَ فِي السِّكَكِ وَيَقُولُونَ مُحَمَّدٌ وَالْخَمِيسُ ـ قَالَ وَالْخَمِيسُ الْجَيْشُ ـ فَظَهَرَ عَلَيْهِمْ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَتَلَ الْمُقَاتِلَةَ وَسَبَى الذَّرَارِيَّ، فَصَارَتْ صَفِيَّةُ لِدِحْيَةَ الْكَلْبِيِّ، وَصَارَتْ لِرَسُولِ اللَّهِ صلى الله عليه وسلم ثُمَّ تَزَوَّجَهَا وَجَعَلَ صَدَاقَهَا عِتْقَهَا‏.‏ فَقَالَ عَبْدُ الْعَزِيزِ لِثَابِتٍ يَا أَبَا مُحَمَّدٍ، أَنْتَ سَأَلْتَ أَنَسًا مَا أَمْهَرَهَا قَالَ أَمْهَرَهَا نَفْسَهَا‏.‏ فَتَبَسَّمَ‏.‏\hadithno{947}\hadithtrans{Narrated Anas bin Malik:Allah's Messenger (ﷺ) offered the Fajr prayer when it was still dark, then he rode and said, 'Allahu Akbar! Khaibar is ruined. When we approach near to a nation, the most unfortunate is the morning of those who have been warned." The people came out into the streets saying, "Muhammad and his army." Allah's Messenger (ﷺ) vanquished them by force and their warriors were killed; the children and women were taken as captives. Safiya was taken by Dihya Al-Kalbi and later she belonged to Allah's Apostle, who married her and her Mahr was her manumission}}
